@@ -4,7 +4,7 @@
 #
 # Author: Slaven Rezic
 #
-# Copyright (C) 2017,2018,2019,2020,2022 Slaven Rezic. All rights reserved.
+# Copyright (C) 2017,2018,2019,2020,2022,2023 Slaven Rezic. All rights reserved.
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 #
@@ -17,7 +17,7 @@ use warnings;
 
 {
     package Doit;
-    our $VERSION = '0.025_59';
+    our $VERSION = '0.026_50';
     $VERSION =~ s{_}{};
 
     use constant IS_WIN => $^O eq 'MSWin32';
@@ -841,7 +841,7 @@ use warnings;
 
 	my @commands;
 	push @commands, {
-			 ($info ? (rv => $code->(), code => sub {}) : (code => $code)),
+			 (code => $code, $info ? (run_always => 1) : ()),
 			 ($quiet ? () : (msg => "@args")),
 			};
 	Doit::Commands->new(@commands);
@@ -924,7 +924,7 @@ use warnings;
 
 	my @commands;
 	push @commands, {
-			 ($info ? (rv => $code->(), code => sub {}) : (code => $code)),
+			 (code => $code, $info ? (run_always => 1) : ()),
 			 ($quiet ? () : (msg => "@args")),
 			};
 	Doit::Commands->new(@commands);
@@ -971,7 +971,7 @@ use warnings;
 
 	my @commands;
 	push @commands, {
-			 ($info ? (rv => $code->(), code => sub {}) : (code => $code)),
+			 (code => $code, $info ? (run_always => 1) : ()),
 			 ($quiet ? () : (msg => "@args")),
 			};
 	Doit::Commands->new(@commands);
@@ -1083,18 +1083,11 @@ use warnings;
 
 	my @commands;
 	push @commands, {
-			 ($info
-			  ? (
-			     rv   => do { $code->(); 1 },
-			     code => sub {},
-			    )
-			  : (
-			     rv   => 1,
-			     code => $code,
-			    )
-			 ),
-			 ($quiet ? () : (msg  => "@args" . _show_cwd($show_cwd))),
-			};
+	    rv   => 1,
+	    code => $code,
+	    ($info ? (run_always => 1) : ()),
+	    ($quiet ? () : (msg  => "@args" . _show_cwd($show_cwd))),
+	};
 	Doit::Commands->new(@commands);
     }
 
@@ -1634,13 +1627,17 @@ use warnings;
 	my $rv;
 	for my $command ($self->commands) {
 	    if (exists $command->{msg}) {
-		Doit::Log::info($command->{msg} . " (dry-run)");
+		Doit::Log::info($command->{msg} . ($command->{run_always} ? "" : " (dry-run)"));
 	    }
 	    if (exists $command->{code}) {
+		my $this_rv;
+		if ($command->{run_always}) {
+		    $this_rv = $command->{code}->();
+		} # else $this_rv stays undefined
 		if (exists $command->{rv}) {
 		    $rv = $command->{rv};
 		} else {
-		    # Well, in dry-run mode we have no real return value...
+		    $rv = $this_rv;
 		}
 	    }
 	}
@@ -1786,6 +1783,14 @@ use warnings;
 	my $sudo = Doit::Sudo->do_connect(dry_run => $self->is_dry_run, components => $self->{components}, %opts);
 	$sudo;
     }
+
+    # XXX does this belong here?
+    sub do_fork {
+	my($self, %opts) = @_;
+	$self->add_component(qw(fork));
+	my $fork = Doit::Fork->do_connect(dry_run => $self->is_dry_run, %opts);
+	$fork;
+    }
 }
 
 {
