@@ -3,7 +3,7 @@
 #
 # Author: Slaven Rezic
 #
-# Copyright (C) 2017,2018 Slaven Rezic. All rights reserved.
+# Copyright (C) 2017,2018,2019 Slaven Rezic. All rights reserved.
 # This package is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 #
@@ -15,11 +15,11 @@ package TestUtil;
 
 use strict;
 use warnings;
-our $VERSION = '0.041';
+our $VERSION = '0.042';
 
 use Exporter 'import';
 our @EXPORT = qw(get_sudo module_exists is_dir_eq);
-our @EXPORT_OK = qw(skip_utime_atime_unreliable);
+our @EXPORT_OK = qw(skip_utime_atime_unreliable signal_kill_num);
 
 use Doit::Log;
 
@@ -113,10 +113,22 @@ sub skip_utime_atime_unreliable (&) {
 	# noatime)
 	Test::More::skip("atime not reliable on this system", 1)
 	    if $^O eq 'netbsd';
+	# See http://www.cpantesters.org/cpan/report/e0265104-b2d4-11e8-bafc-fcd8acac9ab4
+	# Also perl5's t/io/fs.t skips atime tests on haiku.
+	Test::More::skip("atime not set on this system", 1)
+	    if $^O eq 'haiku';
 	$code->();
     }
 }
 
+sub signal_kill_num {
+    if ($^O eq 'haiku') {
+	21; # actually SIGKILLTHR, see https://github.com/haiku/haiku/blob/master/headers/posix/signal.h and http://www.cpantesters.org/cpan/report/e0265104-b2d4-11e8-bafc-fcd8acac9ab4
+    } else {
+	9;
+    }
+}
+
 1;
 
 __END__
